==> haskell-hls-refine-imports-plugin-2.0.0.0-49-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hls-refine-imports-plugin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-refine-imports-plugin
version:              2.0.0.0
visibility:           public
id:                   hls-refine-imports-plugin-2.0.0.0-D9RAB2CZfUiKzFKhxwtge6
key:                  hls-refine-imports-plugin-2.0.0.0-D9RAB2CZfUiKzFKhxwtge6
license:              Apache-2.0
maintainer:           mnf.shih@gmail.com
author:               rayshih
synopsis:             Refine imports plugin for Haskell Language Server
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  a74d2633e135626a53b073b0b8ba531e
exposed:              True
exposed-modules:      Ide.Plugin.RefineImports
import-dirs:
    /usr/lib/ghc-9.4.8/site-local/hls-refine-imports-plugin-2.0.0.0

library-dirs:
    /usr/lib/ghc-9.4.8/site-local/hls-refine-imports-plugin-2.0.0.0

library-dirs-static:
    /usr/lib/ghc-9.4.8/site-local/hls-refine-imports-plugin-2.0.0.0

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-refine-imports-plugin
hs-libraries:         HShls-refine-imports-plugin-2.0.0.0-D9RAB2CZfUiKzFKhxwtge6
depends:
    aeson-2.1.2.1-LDBL5bcX1HC79scYyh3opi base-4.17.2.1 containers-0.6.7
    deepseq-1.4.8.0 ghc-9.4.8 ghcide-2.0.0.0-AOKTdr7dUo5E6gpExUmSTV
    hls-explicit-imports-plugin-2.0.0.0-Ea25cA326VKhrso0RogUm
    hls-graph-2.0.0.0-BGpiuUBrZCwCsk1CEbbWzd
    hls-plugin-api-2.0.0.0-iaubCJYxPJACQ6RJA0OFe
    lsp-1.6.0.0-KkAghWQ0BKUEqGKLNhvLs1 text-2.0.2
    unordered-containers-0.2.20-2kG5VEC3Gy42AwINT9WJ9w

haddock-interfaces:
    /usr/share/doc/haskell-hls-refine-imports-plugin/html/hls-refine-imports-plugin.haddock

haddock-html:         /usr/share/doc/haskell-hls-refine-imports-plugin/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hls-refine-imports-plugin-2.0.0.0-58-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hls-refine-imports-plugin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-refine-imports-plugin
version:              2.0.0.0
visibility:           public
id:                   hls-refine-imports-plugin-2.0.0.0-EZ8iLCFqm75JaNdgAgS4q7
key:                  hls-refine-imports-plugin-2.0.0.0-EZ8iLCFqm75JaNdgAgS4q7
license:              Apache-2.0
maintainer:           mnf.shih@gmail.com
author:               rayshih
synopsis:             Refine imports plugin for Haskell Language Server
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  4967e481e7a1978df21171227d9c4ac4
exposed:              True
exposed-modules:      Ide.Plugin.RefineImports
import-dirs:
    /usr/lib/ghc-9.4.8/site-local/hls-refine-imports-plugin-2.0.0.0

library-dirs:
    /usr/lib/ghc-9.4.8/site-local/hls-refine-imports-plugin-2.0.0.0

library-dirs-static:
    /usr/lib/ghc-9.4.8/site-local/hls-refine-imports-plugin-2.0.0.0

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-refine-imports-plugin
hs-libraries:         HShls-refine-imports-plugin-2.0.0.0-EZ8iLCFqm75JaNdgAgS4q7
depends:
    aeson-2.1.2.1-GOr0sGsn8HVJzt9KhewtB0 base-4.17.2.1 containers-0.6.7
    deepseq-1.4.8.0 ghc-9.4.8 ghcide-2.0.0.0-EHxX854jmvwD5ulayIxyx6
    hls-explicit-imports-plugin-2.0.0.0-6Cmtp0rqZxQ1NIgKEe0MVN
    hls-graph-2.0.0.0-Dwoowae560dEfZKoVLM8Ap
    hls-plugin-api-2.0.0.0-G44fQLihVWI1U4TjtZEXnI
    lsp-1.6.0.0-2EqnYNOWy2LCyRUoXrjR35 text-2.0.2
    unordered-containers-0.2.20-Jl6TkouWI2i1D1jczNV0uv

haddock-interfaces:
    /usr/share/doc/haskell-hls-refine-imports-plugin/html/hls-refine-imports-plugin.haddock

haddock-html:         /usr/share/doc/haskell-hls-refine-imports-plugin/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
